pub struct IncludeOnly(/* private fields */);Expand description
Represents a includeonly tag (<includeonly>)
let includeonly = IncludeOnly::new("foo bar")?;
assert_eq!(
&includeonly.wikitext()?,
"foo bar"
);
assert_eq!(
&includeonly.to_string(),
"<meta typeof=\"mw:Includes/IncludeOnly\" data-mw=\"{"src":"<includeonly>foo bar</includeonly>"}\">"
);
includeonly.set_wikitext("bar foo")?;
assert_eq!(
&includeonly.to_string(),
"<meta typeof=\"mw:Includes/IncludeOnly\" data-mw=\"{"src":"<includeonly>bar foo</includeonly>"}\">"
);See the spec for more details.
Note that while the spec has two nodes, one opening and one closing
(typeof="mw:Includes/IncludeOnly/End"), we only represent the opening
one since Parsoid automatically handles the lack of one or any extra one.
Implementations
Methods from Deref<Target = NodeRef>
Sourcepub fn inclusive_ancestors(&self) -> Ancestors
pub fn inclusive_ancestors(&self) -> Ancestors
Return an iterator of references to this node and its ancestors.
Sourcepub fn ancestors(&self) -> Ancestors
pub fn ancestors(&self) -> Ancestors
Return an iterator of references to this node’s ancestors.
Sourcepub fn inclusive_preceding_siblings(&self) -> Rev<Siblings>
pub fn inclusive_preceding_siblings(&self) -> Rev<Siblings>
Return an iterator of references to this node and the siblings before it.
Sourcepub fn preceding_siblings(&self) -> Rev<Siblings>
pub fn preceding_siblings(&self) -> Rev<Siblings>
Return an iterator of references to this node’s siblings before it.
Sourcepub fn inclusive_following_siblings(&self) -> Siblings
pub fn inclusive_following_siblings(&self) -> Siblings
Return an iterator of references to this node and the siblings after it.
Sourcepub fn following_siblings(&self) -> Siblings
pub fn following_siblings(&self) -> Siblings
Return an iterator of references to this node’s siblings after it.
Sourcepub fn inclusive_descendants(&self) -> Descendants
pub fn inclusive_descendants(&self) -> Descendants
Return an iterator of references to this node and its descendants, in tree order.
Parent nodes appear before the descendants.
Note: this is the NodeEdge::Start items from traverse().
Sourcepub fn descendants(&self) -> Descendants
pub fn descendants(&self) -> Descendants
Return an iterator of references to this node’s descendants, in tree order.
Parent nodes appear before the descendants.
Note: this is the NodeEdge::Start items from traverse().
Sourcepub fn traverse_inclusive(&self) -> Traverse
pub fn traverse_inclusive(&self) -> Traverse
Return an iterator of the start and end edges of this node and its descendants, in tree order.
Sourcepub fn traverse(&self) -> Traverse
pub fn traverse(&self) -> Traverse
Return an iterator of the start and end edges of this node’s descendants, in tree order.
Sourcepub fn select(
&self,
selectors: &str,
) -> Result<Select<Elements<Descendants>>, ()>
pub fn select( &self, selectors: &str, ) -> Result<Select<Elements<Descendants>>, ()>
Return an iterator of the inclusive descendants element that match the given selector list.
Sourcepub fn select_first(
&self,
selectors: &str,
) -> Result<NodeDataRef<ElementData>, ()>
pub fn select_first( &self, selectors: &str, ) -> Result<NodeDataRef<ElementData>, ()>
Return the first inclusive descendants element that match the given selector list.
Sourcepub fn serialize<W>(&self, writer: &mut W) -> Result<(), Error>where
W: Write,
pub fn serialize<W>(&self, writer: &mut W) -> Result<(), Error>where
W: Write,
Serialize this node and its descendants in HTML syntax to the given stream.
Sourcepub fn serialize_to_file<P>(&self, path: P) -> Result<(), Error>
pub fn serialize_to_file<P>(&self, path: P) -> Result<(), Error>
Serialize this node and its descendants in HTML syntax to a new file at the given path.
Sourcepub fn text_contents(&self) -> String
pub fn text_contents(&self) -> String
Return the concatenation of all text nodes in this subtree.
Sourcepub fn append(&self, new_child: NodeRef)
pub fn append(&self, new_child: NodeRef)
Append a new child to this node, after existing children.
The new child is detached from its previous position.
Sourcepub fn prepend(&self, new_child: NodeRef)
pub fn prepend(&self, new_child: NodeRef)
Prepend a new child to this node, before existing children.
The new child is detached from its previous position.
Sourcepub fn insert_after(&self, new_sibling: NodeRef)
pub fn insert_after(&self, new_sibling: NodeRef)
Insert a new sibling after this node.
The new sibling is detached from its previous position.
Sourcepub fn insert_before(&self, new_sibling: NodeRef)
pub fn insert_before(&self, new_sibling: NodeRef)
Insert a new sibling before this node.
The new sibling is detached from its previous position.
Methods from Deref<Target = Node>
Sourcepub fn as_element(&self) -> Option<&ElementData>
pub fn as_element(&self) -> Option<&ElementData>
If this node is an element, return a reference to element-specific data.
Sourcepub fn as_text(&self) -> Option<&RefCell<String>>
pub fn as_text(&self) -> Option<&RefCell<String>>
If this node is a text node, return a reference to its contents.
Sourcepub fn as_comment(&self) -> Option<&RefCell<String>>
pub fn as_comment(&self) -> Option<&RefCell<String>>
If this node is a comment, return a reference to its contents.
Sourcepub fn as_doctype(&self) -> Option<&Doctype>
pub fn as_doctype(&self) -> Option<&Doctype>
If this node is a document, return a reference to doctype-specific data.
Sourcepub fn as_document(&self) -> Option<&DocumentData>
pub fn as_document(&self) -> Option<&DocumentData>
If this node is a document, return a reference to document-specific data.
Sourcepub fn parent(&self) -> Option<NodeRef>
pub fn parent(&self) -> Option<NodeRef>
Return a reference to the parent node, unless this node is the root of the tree.
Sourcepub fn first_child(&self) -> Option<NodeRef>
pub fn first_child(&self) -> Option<NodeRef>
Return a reference to the first child of this node, unless it has no child.
Sourcepub fn last_child(&self) -> Option<NodeRef>
pub fn last_child(&self) -> Option<NodeRef>
Return a reference to the last child of this node, unless it has no child.
Sourcepub fn previous_sibling(&self) -> Option<NodeRef>
pub fn previous_sibling(&self) -> Option<NodeRef>
Return a reference to the previous sibling of this node, unless it is a first child.
Sourcepub fn next_sibling(&self) -> Option<NodeRef>
pub fn next_sibling(&self) -> Option<NodeRef>
Return a reference to the next sibling of this node, unless it is a last child.
Sourcepub fn detach(&self)
pub fn detach(&self)
Detach a node from its parent and siblings. Children are not affected.
To remove a node and its descendants, detach it and drop any strong reference to it.
Sourcepub fn extended_eq(&self, other: &Node, flags: NodeEqFlags) -> bool
pub fn extended_eq(&self, other: &Node, flags: NodeEqFlags) -> bool
Compares if two nodes are equal.